@@ -1,8 +1,13 @@
 # constructor function for emuDBhandle
-emuDBhandle = function(dbName, basePath, UUID, connectionPath, connection=NULL){
+emuDBhandle = function(dbName, 
+                       basePath, 
+                       UUID, 
+                       connectionPath, 
+                       connection = NULL){
   
   if(is.null(connection)){
-    con <- DBI::dbConnect(RSQLite::SQLite(), connectionPath)
+    con <- DBI::dbConnect(RSQLite::SQLite(), 
+                          connectionPath)
   }else{
     con = connection
   }
@@ -18,7 +23,10 @@ emuDBhandle = function(dbName, basePath, UUID, connectionPath, connection=NULL){
     setSQLitePragmas(handle$connection)
   }
   
-  if(connectionPath == ":memory:" || file.exists(file.path(basePath, paste0(dbName, database.cache.suffix))) || !is.null(connection)){
+  if(connectionPath == ":memory:" 
+     || file.exists(file.path(basePath, 
+                              paste0(dbName, database.cache.suffix))) 
+     || !is.null(connection)){
     initialize_emuDbDBI(handle)
   }
   
@@ -44,27 +52,35 @@ print.emuDBhandle = function(x, ...){
 check_emuDBhandle <- function(emuDBhandle, checkCache = TRUE){
   # check if dir and cache actually exist
   if(!dir.exists(emuDBhandle$basePath)){
-    stop("emuDBhandle is invalid as emuDBhandle$basePath doesn't exist! Please reload the emuDB.")
+    stop(paste0("emuDBhandle is invalid as emuDBhandle$basePath ",
+                "doesn't exist! Please reload the emuDB."))
   }
   if(!DBI::dbIsValid(emuDBhandle$connection)){
-    stop("emuDBhandle is invalid as emuDBhandle$connection is not a valid DBI connection! Please reload the emuDB.")
+    stop(paste0("emuDBhandle is invalid as emuDBhandle$connection is not ",
+                "a valid DBI connection! Please reload the emuDB."))
   }
   # from basePath extract dbName and see if DB
-  dbName = stringr::str_replace(basename(emuDBhandle$basePath), pattern = '_emuDB$', replacement = '')
+  dbName = stringr::str_replace(basename(emuDBhandle$basePath), 
+                                pattern = '_emuDB$', 
+                                replacement = '')
   
   if(!file.exists(file.path(emuDBhandle$basePath, paste0(dbName, database.schema.suffix)))){
-    stop(paste0("emuDBhandle is invalid as the directory emuDBhandle$basePath doesn't contain the _DBconfig.json file '", dbName, "_DBconfig.json'. Note that the emuDB directory has to have the same prefix / name as the _DBconfig.json."))
+    stop(paste0("emuDBhandle is invalid as the directory emuDBhandle$basePath doesn't ",
+                "contain the _DBconfig.json file '", dbName, "_DBconfig.json'. Note that ",
+                "the emuDB directory has to have the same prefix / name as the _DBconfig.json."))
   }
   if(checkCache){
     if(!file.exists(file.path(emuDBhandle$basePath, paste0(dbName, database.cache.suffix)))){
-      stop("emuDBhandle is invalid as the directory emuDBhandle$basePath doesn't contain a _emuDBcache.sqlite file! Please reload the emuDB to recreate the emuDBcache.")
+      stop(paste0("emuDBhandle is invalid as the directory emuDBhandle$basePath doesn't contain ",
+                  "a _emuDBcache.sqlite file! Please reload the emuDB to recreate the emuDBcache."))
     }
   }
 }
 
 ##' Print summary of loaded EMU database (emuDB).
 ##' @description Gives an overview of an EMU database.
-##' Prints database name, UUID, base directory path, session and bundle count and informations about signal track, annotation level, attribute and link definitions.
+##' Prints database name, UUID, base directory path, session and bundle 
+##' count and informations about signal track, annotation level, attribute and link definitions.
 ##' @param object emuDBhandle as returned by \code{\link{load_emuDB}}
 ##' @param ... additional arguments affecting the summary produced.
 ##' @export
